@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: BaseFont.pm,v 1.6 2004/06/07 19:44:36 fredo Exp $
+#   $Id: BaseFont.pm,v 1.7 2004/06/15 09:14:41 fredo Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::BaseFont;
@@ -45,7 +45,7 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Resource );
 
-    ( $VERSION ) = '$Revision: 1.6 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/07 19:44:36 $
+    ( $VERSION ) = '$Revision: 1.7 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/15 09:14:41 $
 
 }
 
@@ -638,6 +638,9 @@ alfred reibenschuh.
 =head1 HISTORY
 
     $Log: BaseFont.pm,v $
+    Revision 1.7  2004/06/15 09:14:41  fredo
+    removed cr+lf
+
     Revision 1.6  2004/06/07 19:44:36  fredo
     cleaned out cr+lf for lf
 
