@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: code3of9.pm,v 1.5 2004/06/07 19:44:44 fredo Exp $
+#   $Id: code3of9.pm,v 1.6 2004/06/15 09:14:54 fredo Exp $
 #
 #=======================================================================
 
@@ -45,7 +45,7 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Resource::XObject::Form::BarCode );
 
-    ( $VERSION ) = '$Revision: 1.5 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/07 19:44:44 $
+    ( $VERSION ) = '$Revision: 1.6 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/15 09:14:54 $
 
 }
 
@@ -323,6 +323,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: code3of9.pm,v $
+    Revision 1.6  2004/06/15 09:14:54  fredo
+    removed cr+lf
+
     Revision 1.5  2004/06/07 19:44:44  fredo
     cleaned out cr+lf for lf
 
