@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: PNM.pm,v 1.4 2004/06/07 19:44:44 fredo Exp $
+#   $Id: PNM.pm,v 1.5 2004/06/15 09:14:54 fredo Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::XObject::Image::PNM;
@@ -42,7 +42,7 @@ BEGIN {
 
     use vars qw(@ISA $VERSION);
     @ISA = qw( PDF::API2::Resource::XObject::Image );
-    ( $VERSION ) = '$Revision: 1.4 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/07 19:44:44 $
+    ( $VERSION ) = '$Revision: 1.5 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/15 09:14:54 $
 }
 
 =item $res = PDF::API2::Resource::XObject::Image::PNM->new $pdf, $file [, $name]
@@ -172,6 +172,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: PNM.pm,v $
+    Revision 1.5  2004/06/15 09:14:54  fredo
+    removed cr+lf
+
     Revision 1.4  2004/06/07 19:44:44  fredo
     cleaned out cr+lf for lf
 
